======================================
Generate result tables for assess mode
======================================

.. automodule:: abed.results.assess
    :members:
    :undoc-members:
    :show-inheritance:
